@@ -1110,8 +1110,18 @@ goad_server_activate_exe(GoadServer *sinfo,
     char fd_str [20];
     int i;
     struct sigaction sa;
+    int devnull_fd;
+    int dup2_rv;
 
-    close(0);
+    /* stdin needs to be closed here for some stuff to work (panel?) so 
+     * we do it by attatching /dev/null to it instead of just closing it.
+     * That way, code in the executable that depends on stdin being alive
+     * and kicking will continue to work.
+     */
+    devnull_fd = open ("/dev/null", O_RDONLY);
+    g_assert(devnull_fd != -1);
+    dup2_rv = dup2 (0, devnull_fd);
+    g_assert(dup2_rv != -1);
     
     setsid();
     memset(&sa, 0, sizeof(sa));
